@@ -16,23 +16,27 @@
 __docformat__ = 'restructuredtext'
 
 from zope.interface import implementer
+
 from zope.location.location import inside
 
+
 try:
-    from zope.copy.interfaces import ICopyHook, ResumeCopy
-except ImportError: #pragma NO COVER
+    from zope.copy.interfaces import ICopyHook
+    from zope.copy.interfaces import ResumeCopy
+except ImportError:  # pragma: no cover
     raise NotImplementedError("zope.location.pickling is not supported "
-        "because zope.copy is not available")
+                              "because zope.copy is not available")
 
 
 @implementer(ICopyHook)
-class LocationCopyHook(object):
+class LocationCopyHook:
     """Copy hook to preserve copying referenced objects that are not
     located inside object that's being copied.
     """
+
     def __init__(self, context):
         self.context = context
-    
+
     def __call__(self, toplevel, register):
         if not inside(self.context, toplevel):
             return self.context
